@@ -49,6 +49,9 @@ def to_commented_yaml(filename):
     with open(filename, 'r') as f:
         comment_count = 0
         for line in f:
+            # skip blank line
+            if line.isspace():
+                continue;
             char_count = 0
             spaces = ''
             for char in line:
@@ -185,7 +188,7 @@ def convert(filename, script_path):
     # Preserve typical HOT template key ordering
     od_result = collections.OrderedDict()
     # Need to bump the HOT version so str_replace supports serializing to json
-    od_result['heat_template_version'] = "queens"
+    od_result['heat_template_version'] = "rocky"
     if tpl.get('description'):
         od_result['description'] = description(tpl['description'])
     od_result['parameters'] = tpl['parameters']
