@@ -174,10 +174,10 @@ PARAMETER_DEFINITION_EXCLUSIONS = {'CephPools': ['description',
                                                                'constraints'],
                                    # NOTE(anil): This is a temporary change and
                                    # will be removed once bug #1767070 properly
-                                   # fixed. OVN supports only VLAN and geneve
-                                   # for NeutronNetworkType. But VLAN tenant
-                                   # networks have a limited support in OVN.
-                                   # Till that is fixed, we restrict
+                                   # fixed. OVN supports only VLAN, geneve
+                                   # and flat for NeutronNetworkType. But VLAN
+                                   # tenant networks have a limited support
+                                   # in OVN. Till that is fixed, we restrict
                                    # NeutronNetworkType to 'geneve'.
                                    'NeutronNetworkType': ['description',
                                                           'default',
@@ -1075,13 +1075,15 @@ def validate(filename, param_map):
         if filename.startswith('./roles/'):
             retval = validate_role_name(filename)
 
-        if filename.startswith('./roles/ComputeHCI.yaml'):
+        if filename.startswith('./roles/ComputeHCI.yaml') or \
+                filename.startswith('./roles/ComputeHCIOvsDpdk.yaml'):
             retval |= validate_hci_computehci_role(filename, tpl)
 
         if filename.startswith('./roles/ComputeOvsDpdk.yaml') or \
                 filename.startswith('./roles/ComputeSriov.yaml') or \
                 filename.startswith('./roles/ComputeOvsDpdkRT.yaml') or \
-                filename.startswith('./roles/ComputeSriovRT.yaml'):
+                filename.startswith('./roles/ComputeSriovRT.yaml') or \
+                filename.startswith('./roles/ComputeHCIOvsDpdk.yaml'):
             exclude = [
                 'OS::TripleO::Services::OVNController',
                 'OS::TripleO::Services::ComputeNeutronOvsAgent',
